@@ -66,6 +66,89 @@ def gen_rand(shape, backend, dtype="float64"):
     return x
 
 
+@pytest.mark.parametrize(
+    "f,args,xfail_backends",
+    (
+        ("all", (), ()),
+        ("clip", (0.2, 0.7), ()),
+        ("conj", (), ()),
+        ("cos", (), ()),
+        ("cosh", (), ()),
+        ("count_nonzero", (), ()),
+        ("cumsum", (0,), ("sparse",)),
+        ("diag", (), ("sparse",)),
+        ("diag", (1,), ("sparse",)),
+        ("diag", (-1,), ("sparse",)),
+        ("exp", (), ()),
+        ("imag", (), ()),
+        ("log", (), ()),
+        ("log10", (), ()),
+        ("max", (-1,), ("sparse",)),
+        ("max", (), ()),
+        ("mean", (), ()),
+        ("mean", (0,), ("sparse",)),
+        ("min", (), ()),
+        ("power", (2,), ("sparse",)),
+        ("prod", (), ()),
+        ("ravel", (), ("sparse",)),
+        ("real", (), ()),
+        ("sin", (), ()),
+        ("sinh", (), ()),
+        ("sqrt", (), ()),
+        ("sum", (), ()),
+        ("sum", (1,), ()),
+        ("tan", (), ()),
+        ("tanh", (), ()),
+        ("trace", (), ("sparse",)),
+        ("tril", (), ()),
+        ("tril", (), (1,)),
+        ("tril", (), (-1,)),
+        ("triu", (), ()),
+        ("triu", (), (1,)),
+        ("triu", (), (-1,)),
+    ),
+)
+@pytest.mark.parametrize("backend", BACKENDS)
+def test_unary_functions(f, args, xfail_backends, backend):
+    if backend in xfail_backends:
+        pytest.xfail(f"{backend} doesn't support {f}.")
+
+    xn = ar.do("random.uniform", size=(4, 5), like="numpy")
+    yn = ar.do(f, xn, *args)
+    x = ar.do("asarray", xn, like=backend)
+    y = ar.do(f, x, *args)
+    yt = ar.do("to_numpy", y)
+    assert ar.do("allclose", yt, yn)
+
+
+@pytest.mark.parametrize(
+    "f,args,xfail_backends",
+    (
+        ("add", (), ()),
+        ("allclose", (), ("sparse",)),
+        ("divide", (), ()),
+        ("matmul", (), ()),
+        ("multiply", (), ()),
+        ("subtract", (), ()),
+    ),
+)
+@pytest.mark.parametrize("backend", BACKENDS)
+def test_binary_functions(f, args, xfail_backends, backend):
+    if backend in xfail_backends:
+        pytest.xfail(f"{backend} doesn't support {f}.")
+
+    xan = ar.do("random.uniform", size=(3, 3), like="numpy")
+    xbn = ar.do("random.uniform", size=(3, 3), like="numpy")
+    yn = ar.do(f, xan, xbn, *args)
+
+    xa = ar.do("asarray", xan, like=backend)
+    xb = ar.do("asarray", xbn, like=backend)
+    y = ar.do(f, xa, xb, *args)
+    yt = ar.do("to_numpy", y)
+
+    assert ar.do("allclose", yt, yn)
+
+
 @pytest.mark.parametrize("backend", BACKENDS)
 @pytest.mark.parametrize("fn", ["sqrt", "exp", "sum"])
 def test_basic(backend, fn):
@@ -272,10 +355,6 @@ def test_tril(backend):
         # this won't work for sparse because density < 1
         assert (xln > 0.0).sum() == 13
 
-    if backend == "tensorflow":
-        with pytest.raises(ValueError):
-            ar.do("tril", x, -1)
-
 
 @pytest.mark.parametrize("backend", BACKENDS)
 def test_triu(backend):
@@ -296,10 +375,6 @@ def test_triu(backend):
         # this won't work for sparse because density < 1
         assert (xln > 0.0).sum() == 13
 
-    if backend == "tensorflow":
-        with pytest.raises(ValueError):
-            ar.do("triu", x, 1)
-
 
 @pytest.mark.parametrize("backend", BACKENDS)
 @pytest.mark.parametrize("shape", [(4, 3), (4, 4), (3, 4)])
@@ -892,3 +967,16 @@ def test_creation_with_builtins(fn, args, dtype, expected):
     x = dtype(4)
     y = ar.do(fn, *args, like=x)
     assert y.dtype in expected
+
+
+@pytest.mark.parametrize("backend", BACKENDS)
+def test_indices(backend):
+    if backend == "sparse":
+        pytest.xfail("Sparse doesn't support `indices` function yet.")
+
+    from numpy.testing import assert_array_equal
+
+    x = ar.do("indices", (3, 4), like=backend)
+    xn = ar.to_numpy(x)
+    xe = ar.do("indices", (3, 4), like="numpy")
+    assert_array_equal(xn, xe)
